@@ -15,14 +15,13 @@ Exposes the functions:
 
 import typing
 from typing import Tuple, List, AsyncIterator
-from types import FrameType
-import hashlib
 from threading import Lock, Thread
 import os
 from concurrent.futures import ThreadPoolExecutor
 from asyncio import get_event_loop, sleep
 from contextlib import asynccontextmanager
 
+from asn1crypto import pem as asn1_pem
 from asn1crypto.keys import (
     PublicKeyInfo,
     PublicKeyAlgorithm,
@@ -42,6 +41,7 @@ pool = ThreadPoolExecutor()
 
 @asynccontextmanager
 async def async_lock(lock: Lock) -> AsyncIterator[None]:
+    """Used as a simple async lock"""
     loop = get_event_loop()
     await loop.run_in_executor(pool, lock.acquire)
     try:
@@ -80,33 +80,29 @@ class PKCS11Session:
 
     @classmethod
     async def _healthy_session(cls) -> None:
-        p = Thread(target=cls._open_session, args=())
-        p.start()
-        p.join(timeout=TIMEOUT)
+        thread = Thread(target=cls._open_session, args=())
+        thread.start()
+        thread.join(timeout=TIMEOUT)
 
-        if p.is_alive() or cls._session_status != 0:
+        if thread.is_alive() or cls._session_status != 0:
             if DEBUG:
                 print("Current PKCS11 session is unhealthy, opening a new session")
 
-            p2 = Thread(target=cls._open_session, args=({"force": True}))
-            p2.start()
+            thread2 = Thread(target=cls._open_session, args=({"force": True}))
+            thread2.start()
 
-            # yield to other coroutines while we wait for p2 to join
+            # yield to other coroutines while we wait for thread2 to join
             await sleep(0)
 
-            p2.join(timeout=TIMEOUT)
+            thread2.join(timeout=TIMEOUT)
 
-            if p2.is_alive():
-                raise PKCS11TimeoutException(
-                    "ERROR: Could not get a healthy PKCS11 connection in time"
-                )
+            if thread2.is_alive():
+                raise PKCS11TimeoutException("ERROR: Could not get a healthy PKCS11 connection in time")
         if cls._session_status != 0:
             raise PKCS11UnknownErrorException("ERROR: Could not get a healthy PKCS11 connection")
 
     @classmethod
-    async def import_keypair(
-        cls, key_label: str, public_key: bytes, private_key: bytes
-    ) -> typing.Tuple[PublicKeyInfo, bytes]:
+    async def import_keypair(cls, key_label: str, public_key: bytes, private_key: bytes) -> None:
         """Import a RSA keypair into the PKCS11 device with this label.
         If the label already exists in the PKCS11 device then raise pkcs11.MultipleObjectsReturned.
 
@@ -115,16 +111,13 @@ class PKCS11Session:
         openssl rsa -inform pem -in rsaprivkey.pem -outform der -out PrivateKey.der
         openssl rsa -in rsaprivkey.pem -RSAPublicKey_out -outform DER -out PublicKey.der
 
-        Returns the data for the x509 'Subject Public Key Info'
-        and x509 extension 'Subject Key Identifier' valid for this keypair.
-
         Parameters:
         key_label (str): Keypair label.
         public_key (bytes): Public RSA key in DER form
         private_key (bytes): Private RSA key in DER form
 
         Returns:
-        typing.Tuple[asn1crypto.keys.PublicKeyInfo, bytes]
+        None
         """
 
         async with async_lock(cls._lock):
@@ -138,7 +131,7 @@ class PKCS11Session:
                     label=key_label,
                 )
                 raise MultipleObjectsReturned
-            except NoSuchKey as ex:
+            except NoSuchKey:
                 pass
 
             key_pub = decode_rsa_public_key(public_key)
@@ -152,19 +145,8 @@ class PKCS11Session:
             cls.session.create_object(key_pub)
             cls.session.create_object(key_priv)
 
-            # Create the PublicKeyInfo object
-            rsa_pub = RSAPublicKey.load(encode_rsa_public_key(key_pub))
-            pki = PublicKeyInfo()
-            pka = PublicKeyAlgorithm()
-            pka["algorithm"] = PublicKeyAlgorithmId("rsa")
-            pki["algorithm"] = pka
-            pki["public_key"] = rsa_pub
-            return pki, hashlib.sha1(encode_rsa_public_key(key_pub)).digest()
-
     @classmethod
-    async def create_keypair(
-        cls, key_label: str, key_size: int = 2048
-    ) -> typing.Tuple[PublicKeyInfo, bytes]:
+    async def create_keypair(cls, key_label: str, key_size: int = 2048) -> typing.Tuple[PublicKeyInfo, bytes]:
         """Create a RSA keypair in the PKCS11 device with this label.
         If the label already exists in the PKCS11 device then raise pkcs11.MultipleObjectsReturned.
         Returns the data for the x509 'Subject Public Key Info'
@@ -175,7 +157,7 @@ class PKCS11Session:
         key_size (int = 2048): Size of the key.
 
         Returns:
-        typing.Tuple[asn1crypto.keys.PublicKeyInfo, bytes]
+        typing.Tuple[str, bytes]
         """
 
         async with async_lock(cls._lock):
@@ -194,9 +176,7 @@ class PKCS11Session:
                     print(ex)
                     print("Generating a key since " + "no key with that label was found")
                 # Generate the rsa keypair
-                key_pub, _ = cls.session.generate_keypair(
-                    KeyType.RSA, key_size, store=True, label=key_label
-                )
+                key_pub, _ = cls.session.generate_keypair(KeyType.RSA, key_size, store=True, label=key_label)
 
             # Create the PublicKeyInfo object
             rsa_pub = RSAPublicKey.load(encode_rsa_public_key(key_pub))
@@ -205,7 +185,9 @@ class PKCS11Session:
             pka["algorithm"] = PublicKeyAlgorithmId("rsa")
             pki["algorithm"] = pka
             pki["public_key"] = rsa_pub
-            return pki, hashlib.sha1(encode_rsa_public_key(key_pub)).digest()
+
+            key_pub_pem: bytes = asn1_pem.armor("PUBLIC KEY", pki.dump())
+            return key_pub_pem.decode("utf-8"), pki.sha1
 
     @classmethod
     async def key_labels(cls) -> List[str]:
@@ -322,14 +304,14 @@ class PKCS11Session:
 
     @classmethod
     async def public_key_data(cls, key_label: str) -> Tuple[PublicKeyInfo, bytes]:
-        """Returns the data for the x509 'Public Key Info'
+        """Returns the public key in PEM form
         and 'Key Identifier' valid for this keypair.
 
         Parameters:
         key_label (str): Keypair label.
 
         Returns:
-        typing.Tuple[asn1crypto.keys.PublicKeyInfo, bytes]
+        typing.Tuple[str, bytes]
         """
 
         async with async_lock(cls._lock):
@@ -350,4 +332,5 @@ class PKCS11Session:
             pki["algorithm"] = pka
             pki["public_key"] = rsa_pub
 
-            return pki, hashlib.sha1(encode_rsa_public_key(key_pub)).digest()
+            key_pub_pem: bytes = asn1_pem.armor("PUBLIC KEY", pki.dump())
+            return key_pub_pem.decode("utf-8"), pki.sha1
